@@ -112,7 +112,7 @@ theme_colors = {
         'accent' : '#90caf9', 'pointer' : '#ff5252',
     },
     'Material Light': { 'fg1': '#212121', 'fg2': '#757575', 'fg3': '#264d73',
-        'bg1': '#fafafa', 'bg2': '#f5f5fa', 'bg3': '#f4f4f7',
+        'bg1': '#fafafa', 'bg2': '#f5f5fa', 'bg3': "#e9e9ef",
         'accent': '#1976d2', 'pointer': '#d32f2f',
     },
     'Material Dark': {
@@ -598,9 +598,8 @@ def style_css(colors, fonts, layout, _root = False):
             '^, ^-red,^-green,^-blue, ^-yellow, ^-magenta, ^-cyan': {
                 '--bg-color': 'var(--bg2-color)',
                 'padding': '4px',
-                'border-radius': '4px',
+                'border-radius': '8px',
                 'margin': '0.5em 0',
-                'box-shadow': '0px 0px 1px 0.5px hsl(from var(--bg-color) h s 40% / 0.9) inset !important',
                 'background': 'hsl(from var(--bg-color) h s l / 0.7)', 
             },
             **({
