@@ -94,8 +94,7 @@ class _Buttons:
     end     =  Button(icon= 'plus',layout= Layout(width='auto',height='auto'), tooltip='Go To End of Slides').add_class('Menu-Item').add_class('End-Btn')
     info    =  Button(icon= 'plus',layout= Layout(width='auto',height='auto'), tooltip='Read Information').add_class('Menu-Item').add_class('Info-Btn')
     export  =  Button(description="Export to HTML File",layout= Layout(width='auto',height='auto', margin='0 0 0 var(--jp-widgets-inline-label-width)'))
-    sload   =  Button(description="Load Settings from File",layout= Layout(width='auto',height='auto', margin='0 0 0 var(--jp-widgets-inline-label-width)'), tooltip='File:.ipyslides-assets/settings.json')
-    
+
 @dataclass(frozen=True)
 class _Toggles:
     """
@@ -210,7 +209,7 @@ class Widgets:
                 self.theme,
                 HTML('<b>Additional Features</b>',layout = _html_layout),
                 self.checks.focus, self.checks.notes,self.checks.toast,
-                self.checks.navgui, self.checks.reflow, self.buttons.sload,
+                self.checks.navgui, self.checks.reflow,
                 HTML(html('details',[html('summary','<b>HTML File Export</b>'), how_to_print]).value,layout = _html_layout),
                 self.buttons.export,
                 self.checks.confirm,
